#!/usr/bin/env bash
#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.

# -o nounset does not work if you source the ACS bash profile thing  :)
set -o errexit -o xtrace

JAVA_HOME=/opt/local/java/java8
PATH=$JAVA_HOME/bin:$PATH
ACS_RETAIN=true
ALMASW_ROOTDIR=$(capo -q OodtSettings.almaswRootdir)
ALMASW_RELEASE=$(capo -q OodtSettings.almaswRelease)

source ${ALMASW_ROOTDIR}/${ALMASW_RELEASE}/ACSSW/config/.acs/.bash_profile.acs

# Let's make sure to fail if we try a data fetch inside the DSOC data center
if ! hostname -f | grep -q .cv.; then
    echo "ERROR! Cannot fetch ALMA data outside the NAASC data center!"
    exit 1
fi

# argument 1 is the directory
# argument 2 is optionally "-m" for metadata-only
# argument 3 is (or two) is the ASDM ID

DIRECTORY=$1; shift
DATA_TYPE=$1; shift
DATASET=$1; shift

if [ "$DATA_TYPE" = "SDMonly" ]; then
    asdmExportLight -d "$DIRECTORY/rawdata" -m "$DATASET"
else
    asdmExportLight -d "$DIRECTORY/rawdata" "$DATASET"
fi
